@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.60';
+  $CPAN::Perl::Releases::VERSION = '0.94';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -132,6 +132,18 @@ our $data =
     "tar.bz2" => "L/LB/LBROCARD/perl-5.12.4.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.12.4.tar.gz",
   },
+  "5.12.5-RC1" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.12.5-RC1.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.12.5-RC1.tar.gz",
+  },
+  "5.12.5-RC2" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.12.5-RC2.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.12.5-RC2.tar.gz",
+  },
+  "5.12.5" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.12.5.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.12.5.tar.gz",
+  },
   "5.13.0" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.13.0.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz",
@@ -212,6 +224,18 @@ our $data =
     "tar.bz2" => "F/FL/FLORA/perl-5.14.2.tar.bz2",
     "tar.gz" => "F/FL/FLORA/perl-5.14.2.tar.gz",
   },
+  "5.14.3-RC1" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.14.3-RC1.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.14.3-RC1.tar.gz",
+  },
+  "5.14.3-RC2" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.14.3-RC2.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.14.3-RC2.tar.gz",
+  },
+  "5.14.3" => {
+    "tar.bz2" => "D/DO/DOM/perl-5.14.3.tar.bz2",
+    "tar.gz" => "D/DO/DOM/perl-5.14.3.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -267,6 +291,22 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.16.0.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.16.0.tar.gz",
   },
+  "5.16.1-RC1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.1-RC1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.1-RC1.tar.gz",
+  },
+  "5.16.1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.1.tar.gz",
+  },
+  "5.16.2-RC1" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.2-RC1.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.2-RC1.tar.gz",
+  },
+  "5.16.2" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.16.2.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.16.2.tar.gz",
+  },
   "5.17.0" => {
     "tar.bz2" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.bz2",
     "tar.gz" => "Z/ZE/ZEFRAM/perl-5.17.0.tar.gz",
@@ -275,6 +315,34 @@ our $data =
     "tar.bz2" => "D/DO/DOY/perl-5.17.1.tar.bz2",
     "tar.gz" => "D/DO/DOY/perl-5.17.1.tar.gz",
   },
+  "5.17.2" => {
+    "tar.bz2" => "T/TO/TONYC/perl-5.17.2.tar.bz2",
+    "tar.gz" => "T/TO/TONYC/perl-5.17.2.tar.gz",
+  },
+  "5.17.3" => {
+    "tar.bz2" => "S/SH/SHAY/perl-5.17.3.tar.bz2",
+    "tar.gz" => "S/SH/SHAY/perl-5.17.3.tar.gz",
+  },
+  "5.17.4" => {
+    "tar.bz2" => "F/FL/FLORA/perl-5.17.4.tar.bz2",
+    "tar.gz" => "F/FL/FLORA/perl-5.17.4.tar.gz",
+  },
+  "5.17.5" => {
+    "tar.bz2" => "F/FL/FLORA/perl-5.17.5.tar.bz2",
+    "tar.gz" => "F/FL/FLORA/perl-5.17.5.tar.gz",
+  },
+  "5.17.6" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.17.6.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.17.6.tar.gz",
+  },
+  "5.17.7" => {
+    "tar.bz2" => "D/DR/DROLSKY/perl-5.17.7.tar.bz2",
+    "tar.gz" => "D/DR/DROLSKY/perl-5.17.7.tar.gz",
+  },
+  "5.17.8" => {
+    "tar.bz2" => "A/AR/ARC/perl-5.17.8.tar.bz2",
+    "tar.gz" => "A/AR/ARC/perl-5.17.8.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -373,8 +441,8 @@ sub perl_tarballs {
 
 q|Acme::Why::Did::I::Not::Read::The::Fecking::Memo|;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -383,7 +451,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.60
+version 0.94
 
 =head1 SYNOPSIS
 
@@ -439,10 +507,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Chris Williams.
+This software is copyright (c) 2013 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
